<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:import href="utils.xsl" />

  <xsl:decimal-format name="CZNUM" decimal-separator=',' grouping-separator=' ' />
  <xsl:output method="html" encoding="UTF-8" indent="yes" media-type="text/html" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" />

  <xsl:template match="/">
    <xsl:call-template name="tmplComment" />

    <html>
      <head>
        <meta http-equiv="Content-Language" content="cs"></meta>
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"></meta>
        <title><xsl:value-of select="/AGPRACE/@popis" /></title>
        <style type="text/css">
          <xsl:call-template name="tmplCSS" />
          ul.likeBR {list-style: none outside none; margin: 0px; padding: 0px;}
          ul.likeBR li {margin-bottom: 4px;}
          pre.pozn { font-style: italic; margin: 0px; padding: 0px; }
        </style>
        <script type="text/javascript">
          function showHideElem(sIdElem)
          {
            var elem = document.getElementById(sIdElem);

            if (elem == null)
            {
              return;
            }

            elem.style.display = elem.style.display == "none" ? "" : "none";
          }
        </script>
      </head>
      <body>
        <div style="text-align: center;">
        <h2><xsl:value-of select="/AGPRACE/@popis" /></h2>
        <h4>
          Čas vytvoření souboru <xsl:value-of select="/AGPRACE/@aktualizace" /><br></br>
          Celkem povolení agentur práce: <xsl:value-of select="count(/AGPRACE/POVOLENI)" /><br></br>
        </h4>
        </div>
        <hr/>

        <table class="OKtable OKtbodyTop OKtbodyThDistinct OKthNoWrap OKtbodyThTop OKtbodyTdTop OKbasic2" border="0" width="100%">
          <xsl:apply-templates select="/AGPRACE/POVOLENI" />
        </table>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="/AGPRACE/POVOLENI">
      <tbody>
        <tr>
          <th>Agentura</th>
          <td class="OKbackground" width="100%">
            <b><xsl:value-of select="AGF_PLNE_JMENO" /></b>
            <xsl:if test="AGF_ICO != ''">
              <xsl:text>, IČ </xsl:text>
              <xsl:value-of select="AGF_ICO" />
            </xsl:if>
            <xsl:if test="AGF_WWW != ''">
              <xsl:text>, </xsl:text>
              <b><a href="{AGF_WWW}" class="OKdistinct2 OKbold"><xsl:value-of select="AGF_WWW" /></a></b>
            </xsl:if>
          </td>
        </tr>

        <tr>
          <th valign="top">Pracoviště</th>
          <td width="100%">
            <ul class="likeBR">
              <!--xsl:apply-templates select="KONTAKT[@konos_id != '']"/-->
              <xsl:apply-templates select="KONTAKT"/>
            </ul>
          </td>
        </tr>

      <xsl:if test="AGF_PREDMET_PODNIKANI != ''">
        <tr>
          <th>Předmět podnikání</th>
          <td><xsl:value-of select="AGF_PREDMET_PODNIKANI" /></td>
        </tr>
      </xsl:if>

      <xsl:if test="not(AGPOV_FORMA_ZPROSTR = 'A' or AGPOV_FORMA_ZAMEST = 'A' or AGPOV_FORMA_PORAD = 'A') and (AGPOV_ROZSAH_CR_OCR = 'A' or AGPOV_ROZSAH_CR_OEU = 'A' or AGPOV_ROZSAH_CR_CIZ = 'A' or AGPOV_ROZSAH_ZAH_OCR = 'A' or AGPOV_ROZSAH_ZAH_OEU = 'A')">
        <tr>
          <th>Rozsah činnosti</th>
          <th>&#xA0;</th>
        </tr>
        <xsl:if test="AGPOV_ROZSAH_CR_OCR = 'A' or AGPOV_ROZSAH_CR_OEU = 'A' or AGPOV_ROZSAH_CR_CIZ = 'A'">
          <tr>
            <th>&#xA0;&#xA0;&#xA0;A) Na území ČR</th>
            <td valign="top" width="100%">
              <xsl:apply-templates select="." mode="rozsahCr"/>
              <xsl:apply-templates select="." mode="formaZprC"/>
            </td>
          </tr>
        </xsl:if>

        <xsl:if test="AGPOV_ROZSAH_ZAH_OCR = 'A' or AGPOV_ROZSAH_ZAH_OEU = 'A'">
          <tr>
            <th>&#xA0;&#xA0;&#xA0;B) Do zahraničí</th>
            <td valign="top" width="100%">
              <xsl:apply-templates select="." mode="rozsahZah"/>
              <xsl:apply-templates select="." mode="formaZprZ"/>
            </td>
          </tr>
        </xsl:if>
      </xsl:if>

      <xsl:if test="AGPOV_FORMA_ZPROSTR = 'A' or AGPOV_FORMA_ZAMEST = 'A' or AGPOV_FORMA_PORAD = 'A'">
        <tr>
          <th>Forma zprostředkování</th>
          <td valign="top" width="100%">
            <xsl:apply-templates select="." mode="formaZpr"/>
          </td>
        </tr>
      </xsl:if>

        <tr><th>Druhy prací</th><td width="100%"><xsl:value-of select="AGPOV_DRUHY_PRACI" /></td></tr>

      <xsl:if test="AGPOV_MISTO_PODNIKANI != ''">
        <tr>
          <th>Místo zprostředkování</th>
          <td><xsl:value-of select="AGPOV_MISTO_PODNIKANI" /></td>
        </tr>
      </xsl:if>

        <tr>
          <th>Platnost od/do</th><td width="100%">
            <xsl:value-of select="concat(number(substring(AGPOV_POVOLENO_OD, 9, 2)), '.', number(substring(AGPOV_POVOLENO_OD, 6, 2)), '.', number(substring(AGPOV_POVOLENO_OD, 1, 4)))" />
            <xsl:text> - </xsl:text>
            <xsl:if test="AGPOV_POVOLENO_DO = '2200-01-01'">
              <xsl:text>Neomezeně</xsl:text>
            </xsl:if>
            <xsl:if test="AGPOV_POVOLENO_DO != '2200-01-01'">
              <xsl:value-of select="concat(number(substring(AGPOV_POVOLENO_DO, 9, 2)), '.', number(substring(AGPOV_POVOLENO_DO, 6, 2)), '.', number(substring(AGPOV_POVOLENO_DO, 1, 4)))" />
            </xsl:if>
          </td>
        </tr>
        <tr>
          <td colspan="2"><hr class="OKborder" style="border-right: 0px none; height: 1px; border-bottom-width: 0px; border-left-width: 0px;"/></td>
        </tr>
      </tbody>
  </xsl:template>

  <xsl:template match="KONTAKT">
    <li>
      <xsl:if test="JE_SIDLO_FIRMY = 'A'">
        <xsl:if test="@konos_id != ''">
          <xsl:text>Bydliště: </xsl:text>
        </xsl:if>
        <xsl:if test="@konos_id = ''">
          <xsl:text>Sídlo: </xsl:text>
        </xsl:if>
        <xsl:text disable-output-escaping="yes"><![CDATA[<span style="color: rgb(102, 102, 102);">]]></xsl:text>
      </xsl:if>

      <b>
      <xsl:if test="AGK_PLNE_JMENO != ''">
        <xsl:value-of select="AGK_PLNE_JMENO" />
      </xsl:if>
      <xsl:if test="ADRESA_TEXT != ''">
        <xsl:if test="AGK_PLNE_JMENO != ''">
          <xsl:text>, </xsl:text>
        </xsl:if>
        <xsl:value-of select="ADRESA_TEXT" />
      </xsl:if>
      </b>
      <xsl:if test="AGP_EMAIL != ''">
        <xsl:text>, e-mail: </xsl:text>
        <a href="mailto:{AGP_EMAIL}" class="OKdistinct2 OKbold"><xsl:value-of select="AGP_EMAIL" /></a>
      </xsl:if>
      <xsl:if test="AGP_TELEFON != ''">
        <xsl:text>, telefon: </xsl:text>
        <xsl:value-of select="AGP_TELEFON" />
      </xsl:if>
      <xsl:if test="AGP_FAX != ''">
        <xsl:text>, fax: </xsl:text>
        <xsl:value-of select="AGP_FAX" />
      </xsl:if>
      <xsl:if test="AGP_POZNAMKA != '' or AGK_POZNAMKA != ''">
        <br/>
        <xsl:text>Poznámka:</xsl:text>
        <xsl:if test="AGP_POZNAMKA != ''">
          <pre class="OKbasic2 pozn"><xsl:value-of select="AGP_POZNAMKA" /></pre>
        </xsl:if>
        <xsl:if test="AGK_POZNAMKA != ''">
          <xsl:if test="AGP_POZNAMKA != ''">
            <br/>
          </xsl:if>
          <pre class="OKbasic2 pozn"><xsl:value-of select="AGK_POZNAMKA" /></pre>
        </xsl:if>
      </xsl:if>

      <xsl:if test="JE_SIDLO_FIRMY = 'A'">
        <xsl:text disable-output-escaping="yes"><![CDATA[</span>]]></xsl:text>
      </xsl:if>
    </li>
  </xsl:template>

  <xsl:template name="formaZpr">
      <xsl:param name="nadpis" />
      <xsl:param name="zprostr" />
      <xsl:param name="zamest" />
      <xsl:param name="porad" />
      <xsl:if test="$zprostr = 'A' or $zamest = 'A' or $porad = 'A'">
        <xsl:if test="$nadpis != ''">
          <b><xsl:value-of select="$nadpis" /></b>
        </xsl:if>
        <ul class="likeBR">
        <xsl:if test="$zprostr = 'A'">
          <li>a) Vyhledání zaměstnání pro fyzickou osobu, která se o práci uchází, a vyhledání zaměstnanců pro zaměstnavatele, který hledá nové pracovní síly.</li>
        </xsl:if>
        <xsl:if test="$zamest = 'A'">
          <li>b) Zaměstnávání fyzických osob za účelem výkonu jejich práce pro uživatele, kterým se rozumí jiná právnická nebo fyzická osoba, která práci přiděluje a dohlíží na její provedení.</li>
        </xsl:if>
        <xsl:if test="$porad = 'A'">
          <li>c) Poradenská a informační činnost v oblasti pracovních příležitostí.</li>
        </xsl:if>
        </ul>
      </xsl:if>
  </xsl:template>

  <xsl:template match="POVOLENI" mode="formaZprC">
      <xsl:call-template name="formaZpr">
        <xsl:with-param name="nadpis">Forma zprostředkování</xsl:with-param>
        <xsl:with-param name="zprostr"><xsl:value-of select="AGPOV_FORMAC_ZPROSTR" /></xsl:with-param>
        <xsl:with-param name="zamest"><xsl:value-of select="AGPOV_FORMAC_ZAMEST" /></xsl:with-param>
        <xsl:with-param name="porad"><xsl:value-of select="AGPOV_FORMAC_PORAD" /></xsl:with-param>
      </xsl:call-template>
  </xsl:template>

  <xsl:template match="POVOLENI" mode="formaZprZ">
      <xsl:call-template name="formaZpr">
        <xsl:with-param name="nadpis">Forma zprostředkování</xsl:with-param>
        <xsl:with-param name="zprostr"><xsl:value-of select="AGPOV_FORMAZ_ZPROSTR" /></xsl:with-param>
        <xsl:with-param name="zamest"><xsl:value-of select="AGPOV_FORMAZ_ZAMEST" /></xsl:with-param>
        <xsl:with-param name="porad"><xsl:value-of select="AGPOV_FORMAZ_PORAD" /></xsl:with-param>
      </xsl:call-template>
  </xsl:template>

  <xsl:template match="POVOLENI" mode="formaZpr">
      <xsl:call-template name="formaZpr">
        <xsl:with-param name="nadpis"></xsl:with-param>
        <xsl:with-param name="zprostr"><xsl:value-of select="AGPOV_FORMA_ZPROSTR" /></xsl:with-param>
        <xsl:with-param name="zamest"><xsl:value-of select="AGPOV_FORMA_ZAMEST" /></xsl:with-param>
        <xsl:with-param name="porad"><xsl:value-of select="AGPOV_FORMA_PORAD" /></xsl:with-param>
      </xsl:call-template>
  </xsl:template>

  <xsl:template match="POVOLENI" mode="rozsahCr">
      <xsl:if test="AGPOV_ROZSAH_CR_OCR = 'A' or AGPOV_ROZSAH_CR_OEU = 'A' or AGPOV_ROZSAH_CR_CIZ = 'A'">
        <b>Předmět povolení</b>
        <ul class="likeBR">
        <xsl:if test="AGPOV_ROZSAH_CR_OCR = 'A'">
          <li>Občanům ČR</li>
        </xsl:if>
        <xsl:if test="AGPOV_ROZSAH_CR_OEU = 'A'">
          <li>
            <xsl:text>Občanům EU/EHP</xsl:text>
            <xsl:if test="AGPOV_ROZSAH_CR_OEU_STATY != ''">
              <xsl:text> ze států: </xsl:text><xsl:value-of select="AGPOV_ROZSAH_CR_OEU_STATY" />
            </xsl:if>
          </li>
        </xsl:if>
        <xsl:if test="AGPOV_ROZSAH_CR_CIZ = 'A'">
          <li>
            <xsl:text>Cizincům mimo EU/EHP</xsl:text>
            <xsl:if test="AGPOV_ROZSAH_CR_CIZ_STATY != ''">
              <xsl:text> ze států: </xsl:text><xsl:value-of select="AGPOV_ROZSAH_CR_CIZ_STATY" />
            </xsl:if>
          </li>
        </xsl:if>
        </ul>
      </xsl:if>
  </xsl:template>

  <xsl:template match="POVOLENI" mode="rozsahZah">
      <b>Předmět povolení</b>
      <ul class="likeBR">
      <xsl:if test="AGPOV_ROZSAH_ZAH_OCR = 'A'">
        <li>
          <xsl:text>Občanům ČR</xsl:text>
          <xsl:if test="AGPOV_ROZSAH_ZAH_OCR_STATY != ''">
            <xsl:text> do států: </xsl:text><xsl:value-of select="AGPOV_ROZSAH_ZAH_OCR_STATY" />
          </xsl:if>
        </li>
      </xsl:if>
      <xsl:if test="AGPOV_ROZSAH_ZAH_OEU = 'A'">
        <li>
          <xsl:text>Občanům EU/EHP</xsl:text>
          <xsl:if test="AGPOV_ROZSAH_ZAH_OEU_STATY != ''">
            <xsl:text> do států: </xsl:text><xsl:value-of select="AGPOV_ROZSAH_ZAH_OEU_STATY" />
          </xsl:if>
        </li>
      </xsl:if>
      </ul>
  </xsl:template>

</xsl:stylesheet>
